==> mutt-1.3.3i.tar.gz: mutt-1.3.3/charset.h <==
/*
 * Copyright (C) 1999-2000 Thomas Roessler <roessler@guug.de>
 *
 *     This program is free software; you can redistribute it and/or modify
 *     it under the terms of the GNU General Public License as published by
 *     the Free Software Foundation; either version 2 of the License, or
 *     (at your option) any later version.
 *
 *     This program is distributed in the hope that it will be useful,
 *     but WITHOUT ANY WARRANTY; without even the implied warranty of
 *     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *     GNU General Public License for more details.
 *
 *     You should have received a copy of the GNU General Public License
 *     along with this program; if not, write to the Free Software
 *     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111, USA.
 */

#ifndef _CHARSET_H
#define _CHARSET_H

#include <iconv.h>

#define DECODER_BUFFSIZE 4096

struct decoder_buff
{
  size_t size, used;
  char buff[DECODER_BUFFSIZE];
};

typedef struct decoder
{
  /*short src_is_utf8;*/
  short just_take_id;
  short forced;
  char *outrepl;

  /* conversion descriptor */
  iconv_t cd;

  /* the buffers */
  struct decoder_buff in;
  struct decoder_buff out;
  struct decoder_buff *_in;
} 
DECODER;

DECODER *mutt_open_decoder (const char *, const char *);
void mutt_decoder_push (DECODER *, void *, size_t, size_t *);
void mutt_decoder_pop (DECODER *, void *, size_t, size_t *);
void mutt_decoder_pop_to_state (DECODER *, STATE *);
void mutt_free_decoder (DECODER **);
int mutt_decoder_push_one (DECODER *, char);

int mutt_recode_file (const char *, const char *, const char *);

int mutt_convert_string (char **, const char *, const char *);

iconv_t mutt_iconv_open (const char *, const char *);
size_t mutt_iconv (iconv_t, const char **, size_t *, char **, size_t *, const char **, const char *);

typedef void * FGETCONV;

FGETCONV *fgetconv_open (FILE *, const char *, const char *);
int fgetconv (FGETCONV *);
void fgetconv_close (FGETCONV *);

#ifdef HAVE_LANGINFO_CODESET
void mutt_set_langinfo_charset (void);
#endif

#endif /* _CHARSET_H */

==> mutt-1.3.99i.tar.gz: mutt-1.3.99/charset.h <==
/*
 * Copyright (C) 1999-2000 Thomas Roessler <roessler@guug.de>
 *
 *     This program is free software; you can redistribute it and/or modify
 *     it under the terms of the GNU General Public License as published by
 *     the Free Software Foundation; either version 2 of the License, or
 *     (at your option) any later version.
 *
 *     This program is distributed in the hope that it will be useful,
 *     but WITHOUT ANY WARRANTY; without even the implied warranty of
 *     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *     GNU General Public License for more details.
 *
 *     You should have received a copy of the GNU General Public License
 *     along with this program; if not, write to the Free Software
 *     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111, USA.
 */

#ifndef _CHARSET_H
#define _CHARSET_H

#ifdef HAVE_ICONV_H
#include <iconv.h>
#endif

#ifndef HAVE_ICONV_T_DEF
typedef void *iconv_t;
#endif

#ifndef HAVE_ICONV
iconv_t iconv_open (const char *, const char *);
size_t iconv (iconv_t, const char **, size_t *, char **, size_t *);
int iconv_close (iconv_t);
#endif

int mutt_convert_string (char **, const char *, const char *, int);

iconv_t mutt_iconv_open (const char *, const char *, int);
size_t mutt_iconv (iconv_t, ICONV_CONST char **, size_t *, char **, size_t *, ICONV_CONST char **, const char *);

typedef void * FGETCONV;

FGETCONV *fgetconv_open (FILE *, const char *, const char *, int);
int fgetconv (FGETCONV *);
void fgetconv_close (FGETCONV **);

void mutt_set_langinfo_charset (void);

#define M_ICONV_HOOK_FROM 1
#define M_ICONV_HOOK_TO   2

#endif /* _CHARSET_H */
